aboutsummaryrefslogtreecommitdiff
path: root/targphys.h
diff options
context:
space:
mode:
authormalc <av1474@comtv.ru>2009-10-01 22:20:47 +0400
committermalc <av1474@comtv.ru>2009-10-01 22:45:02 +0400
commit99a0949b720a0936da2052cb9a46db04ffc6db29 (patch)
treef9e39633853e35b49fc4465337cc196b9650866e /targphys.h
parentbc6291a1b95a2c4c546fde6e5cb4c68366f06649 (diff)
Get rid of _t suffix
Some not so obvious bits, slirp and Xen were left alone for the time being. Signed-off-by: malc <av1474@comtv.ru>
Diffstat (limited to 'targphys.h')
-rw-r--r--targphys.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/targphys.h b/targphys.h
index 99ab23c7a7..2a5b1bd546 100644
--- a/targphys.h
+++ b/targphys.h
@@ -1,21 +1,21 @@
/* Define target_phys_addr_t if it exists. */
#ifndef TARGPHYS_H
#define TARGPHYS_H
#ifdef TARGET_PHYS_ADDR_BITS
/* target_phys_addr_t is the type of a physical address (its size can
be different from 'target_ulong'). We have sizeof(target_phys_addr)
= max(sizeof(unsigned long),
sizeof(size_of_target_physical_address)) because we must pass a
host pointer to memory operations in some cases */
#if TARGET_PHYS_ADDR_BITS == 32
-typedef uint32_t target_phys_addr_t;
+typedef uint32_t a_target_phys_addr;
#define TARGET_PHYS_ADDR_MAX UINT32_MAX
#define TARGET_FMT_plx "%08x"
#elif TARGET_PHYS_ADDR_BITS == 64
-typedef uint64_t target_phys_addr_t;
+typedef uint64_t a_target_phys_addr;
#define TARGET_PHYS_ADDR_MAX UINT64_MAX
#define TARGET_FMT_plx "%016" PRIx64
#endif
@@ -1,21 +1,21 @@
-/* Define target_phys_addr_t if it exists. */
+/* Define a_target_phys_addr if it exists. */
#ifndef TARGPHYS_H
#define TARGPHYS_H
@@ -1,21 +1,21 @@
#define TARGPHYS_H
#ifdef TARGET_PHYS_ADDR_BITS
-/* target_phys_addr_t is the type of a physical address (its size can
+/* a_target_phys_addr is the type of a physical address (its size can
be different from 'target_ulong'). We have sizeof(target_phys_addr)
= max(sizeof(unsigned long),